@@ -15,11 +15,7 @@
 #include <QGuiApplication>
 #include <QTimerEvent>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 
 static xcb_window_t get_selection_owner(xcb_connection_t *c, xcb_atom_t selection)
 {
@@ -93,11 +89,7 @@ public:
     static Private *create(KSelectionOwner *owner, const char *selection_P, xcb_connection_t *c, xcb_window_t root);
 
 protected:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *) override
-#else
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *) override
-#endif
     {
         if (eventType != "xcb_generic_event_t") {
             return false;
